@@ -11,6 +11,9 @@ sip.setapi('QVariant', 2)
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 
+from utils import *
+from notifications import KhweeteurNotification
+
 KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
 KHWEETEUR_TWITTER_CONSUMER_SECRET = 'lbKAvvBiyTlFsJfb755t3y1LVwB0RaoMoDwLD14VvU'
 KHWEETEUR_IDENTICA_CONSUMER_KEY = 'c7e86efd4cb951871200440ad1774413'
